@@ -1304,8 +1304,7 @@ public class CBUtility
 
     /**
      * Checks if we have write permissions to a potential configuration directory.
-     * If we have theoretical write permission, but the actual directory doesn't exist, create it
-     * creates it.
+     * If we have theoretical write permission, but the actual directory doesn't exist, create it.
      *
      * @param workingDirectory
      * @return
@@ -1322,7 +1321,7 @@ public class CBUtility
             if (!jx.exists())
                 jx.mkdirs();
 
-            File testFile = new File(jx, "bloop123987.snorf");
+            File testFile = new File(jx, "jx_file_write.test");
 
             if (testFile.exists())
                 testFile.delete();
