@@ -161,6 +161,7 @@ public class ConnectionData
 
     public ConnectionData()
     {
+
     }
 
     /**
@@ -422,22 +423,23 @@ public class ConnectionData
 
     public String toString()
     {
-        return new String("baseDN: " + baseDN +
+        return new String("baseDN: " + ((baseDN==null)?"null":baseDN) +
                 "\nversion: " + Integer.toString(version) +
-                "\nurl: " + url +
-                "\nuserDN: " + userDN +
-                "\nreferralType: " + referralType +
-                "\naliasType: " + aliasType +
+                "\nurl: " + ((url==null)?"null":url) +
+                "\nuserDN: " + ((userDN==null)?"null":userDN) +
+                "\npwd: " + ((pwd==null)?"null":"***") +
+                "\nreferralType: " + ((referralType==null)?"null":referralType) +
+                "\naliasType: " + ((aliasType==null)?"null":aliasType) +
                 "\nuseSSL: " + String.valueOf(useSSL) +
-                "\ncacerts: " + cacerts +
-                "\nclientcerts: " + clientcerts +
-                "\ncaKeystoreType: " + caKeystoreType +
-                "\nclientKeystoreType: " + clientKeystoreType +
-                "\ncaKeystorePwd; " + new String(caKeystorePwd) +
-                "\nclientKeystorePwd: " + new String(clientKeystorePwd) +
+                "\ncacerts: " + ((cacerts==null)?"null":cacerts) +
+                "\nclientcerts: " + ((clientcerts==null)?"null":clientcerts) +
+                "\ncaKeystoreType: " + ((caKeystoreType==null)?"null":caKeystoreType) +
+                "\nclientKeystoreType: " + ((clientKeystoreType==null)?"null":clientKeystoreType) +
+                "\ncaKeystorePwd; " + ((caKeystorePwd==null)?"null":new String(caKeystorePwd)) +
+                "\nclientKeystorePwd: " + ((clientKeystorePwd==null)?"null":new String(clientKeystorePwd)) +
                 "\ntracing: " + String.valueOf(tracing) +
-                "\nprotocol: " + protocol +
-                "\nsslSocketFactory: " + sslSocketFactory +
+                "\nprotocol: " + ((protocol==null)?"null":protocol) +
+                "\nsslSocketFactory: " + ((sslSocketFactory==null)?"null":sslSocketFactory) +
                 "\nuseGSSAPI: " + String.valueOf(useGSSAPI));
     }
 
