@@ -458,84 +458,115 @@ public abstract class CBOpenConWin extends CBDialog
         return "ldap://" + host + ":" + port;
     }
 
+    /**
+     * This assembles a connection data object from the UI fields filled in by the user.
+     * In a pinch, this method can be used to read off the saved connection details
+     * from a user template, without actually showing a UI.
+     * @return
+     * @throws Exception
+     */
+    public ConnectionData getConnectionData()
+            throws Exception
+    {
+        return getConnectionData(null);
+    }
 
+    /**
+     * Allows an external password to be supplied
+     * @return
+     * @throws Exception
+     */
+    public ConnectionData getConnectionData(char[] defaultPwd)
+            throws Exception
+    {
+
+        // XXX TODO: this is kinda weird - this line blew away the setup of ssl info and broke SSL, why did I stick it in, and when?
+        //ConnectionData connection = new ConnectionData();
+        
+        ConnectionData connection = newCon;
+
+
+        log.fine("read values: " + hostName.getText() + ":" + port.getText());
+
+        /*
+         *    Read Host and Port
+         */
+
+        String url = getURL();  // throws exceptions if URL is bad.
+
+        connection.setURL(url);
+
+        if (userMessage != null) // possibly null in batch mode
+            userMessage.setText(CBIntText.get("Opening Connection To") + " " + url);
+
+        /*
+         *   ldap version number
+         */
+
+        if (version.getSelectedItem() == LDAPV2)
+            connection.version = 2;
+        else // default for both ldap and dsml
+            connection.version = 3;
+
+        /*
+         *    Security Magic
+         */
+
+        int securityLevel = checkSecurityLevel();
+
+        connection.userDN = null;
+        connection.clearPasswords();
+
+        connection.useGSSAPI = false;
+
+        if (securityLevel == USER_AUTH || securityLevel == SSL_USER_AUTH)
+        {
+            connection.userDN = managerDN.getText().trim();
+
+            connection.pwd = (defaultPwd==null)?password.getPassword():defaultPwd;
+            if ((connection.pwd.length) == 0)
+            {					//TE: make sure the user has entered a password.
+                throw new Exception(CBIntText.get("No Password Provided.  Please enter a password."));
+            }
+        }
+        else if (securityLevel == SASL)
+        {
+            connection.clientKeystorePwd = (defaultPwd==null)?password.getPassword():defaultPwd;
+
+            if ((connection.clientKeystorePwd.length) == 0)
+            {				//TE: make sure the user has entered a password.
+                throw new Exception(CBIntText.get("No Password Provided.  Please enter a password."));
+            }
+        }
+        //Vadim: GSSAPI
+        else if (securityLevel == GSSAPI)
+        {
+            // username & password are only used if an existing kerberos keystore cannot be found;
+            // we'll prompt the user for them elsewhere if neccessary.
+
+            connection.useGSSAPI = true;
+        }
+
+        setVisible(false);
+
+        connection.useSSL = (securityLevel >= SSL_NO_AUTH && securityLevel != GSSAPI);
+
+        connection.baseDN = baseDN.getText();
+
+        connection.templateName = myTemplater.getCurrentTemplateName();
+
+        return connection;
+    }
+        
     /**
      * Over-ride base class method that is called when the OK button is hit.
      */
 
     public void doOK()
     {
-
         try
         {
-            log.fine("read values: " + hostName.getText() + ":" + port.getText());
-
-            /*
-             *    Read Host and Port
-             */
-
-            String url = getURL();  // throws exceptions if URL is bad.
-
-            newCon.setURL(url);
-
-            userMessage.setText(CBIntText.get("Opening Connection To") + " " + url);
-
-            /*
-             *   ldap version number
-             */
-
-            if (version.getSelectedItem() == LDAPV2)
-                newCon.version = 2;
-            else // default for both ldap and dsml
-                newCon.version = 3;
-
-
-            /*
-             *    Security Magic
-             */
-
-            int securityLevel = checkSecurityLevel();
-
-            newCon.userDN = null;
-            newCon.clearPasswords();
-
-            newCon.useGSSAPI = false;
-
-            if (securityLevel == USER_AUTH || securityLevel == SSL_USER_AUTH)
-            {
-                newCon.userDN = managerDN.getText().trim();
-                newCon.pwd = password.getPassword();
-                if ((newCon.pwd.length) == 0)
-                {					//TE: make sure the user has entered a password.
-                    throw new Exception(CBIntText.get("No Password Provided.  Please enter a password."));
-                }
-            }
-            else if (securityLevel == SASL)
-            {
-                newCon.clientKeystorePwd = password.getPassword();
-                if ((newCon.clientKeystorePwd.length) == 0)
-                {				//TE: make sure the user has entered a password.
-                    throw new Exception(CBIntText.get("No Password Provided.  Please enter a password."));
-                }
-            }
-            //Vadim: GSSAPI
-            else if (securityLevel == GSSAPI)
-            {
-                // username & password are only used if an existing kerberos keystore cannot be found;
-                // we'll prompt the user for them elsewhere if neccessary.
-
-                newCon.useGSSAPI = true;
-            }
-
-            setVisible(false);
-
-            newCon.useSSL = (securityLevel >= SSL_NO_AUTH && securityLevel != GSSAPI);
-
-            newCon.baseDN = baseDN.getText();
-
-            newCon.templateName = myTemplater.getCurrentTemplateName();
-
-
+            newCon = getConnectionData();
         }
         catch (Exception err)
         {   // a bunch of things may throw exceptions; at this stage we haven't tried
@@ -559,7 +590,6 @@ public abstract class CBOpenConWin extends CBDialog
         // Now the data has been read, send it off to the connect method to make the connection.
 
         connect(newCon);
-
     }
 
     /**
