@@ -629,8 +629,15 @@ public class JXplorerBrowser extends JFrame                     // Applet
         return status;    // in case someone is interested...
     }
 
+    /**
+     * Gets the current display mode.
+     * On error returns 'BROWSE'.
+     * @return
+     */
     public DisplayMode getDisplayMode()
     {
+        if (treeTabPane == null) return DisplayMode.BROWSE;
+        
         Component treePane = treeTabPane.getSelectedComponent();
         if (treePane == explorePanel)                // Explore.
             return DisplayMode.BROWSE;
@@ -639,7 +646,7 @@ public class JXplorerBrowser extends JFrame                     // Applet
         else if (treePane == schemaPanel)           // Schema.
             return DisplayMode.SCHEMA;
         else
-            return null;
+            return DisplayMode.BROWSE;
     }
 
     /**
