@@ -1254,13 +1254,18 @@ public class MainMenu extends JMenuBar
     {
         // Open source license...
         File licence = new File(System.getProperty("user.dir") + File.separator + "licence.txt");
-        if (licence.exists())
-        {
-            String textBody = JXConfig.version+"\n\nCopyright \u00a9 2005 CA. All rights reserved.";
 
-            try
-            {
+            String textBody = JXConfig.version+"\n\n";
+
+        try
+        {
+            if (licence.exists())
                 textBody = CBUtility.readTextFile(licence);
+        }
+        catch (IOException e)
+        {
+            log.severe("unable to read licence file - check 'licence.txt' for CA Open Source licence details");            
+        }
                 textBody = JXConfig.version + "\n" +
                            "\nWritten by: Chris Betts" +
                            "\n            Trudi Ersvaer\n" +
@@ -1269,8 +1274,6 @@ public class MainMenu extends JMenuBar
                            "\n            Van Bui\n\n\n" +
                            textBody;
 
-            }
-            catch (IOException e) {} // should still be set to original CA text.
 
             CBAbout about = new CBAbout(browser, textBody, new ImageIcon(Theme.getInstance().getDirTemplates() + "JXAboutBottom.gif"),
                         new ImageIcon(Theme.getInstance().getDirTemplates() + "JXAboutTop.gif"), CBIntText.get("OK"), CBIntText.get("Close this window"), CBIntText.get("About JXplorer"));
@@ -1279,26 +1282,7 @@ public class MainMenu extends JMenuBar
             about.setResizable(true);
             CBUtility.center(about, browser);
             about.setVisible(true);
-        }
-        else
-        {
-            /* I don't think we can ship with the CA tau code?? - CB
-            // CA license...
-            File ca_licence = new File(System.getProperty("user.dir") + File.separator + "ca_license.txt");
-            String textBody = null;
-            try
-            {
-                textBody = CBUtility.readTextFile(ca_licence);
-            }
-            catch (IOException e)
-            {
-                e.printStackTrace();
-            }
 
-            AboutBox about = new AboutBox(jxplorer, "eTrust\u2122 Directory JXplorer", JXplorer.version, "", "", textBody, HelpIDs.CONTACT_SUPPORT);
-            about.setVisible(true);
-            */
-        }
     }
 
 
