@@ -30,7 +30,6 @@ import com.ca.commons.jndi.*;
 
 public class JNDIDataBroker extends DataBroker
 {
-//  	private static final String DEFAULT_CTX = "com.sun.jndi.ldap.LdapCtxFactory";
     private static final int    SEARCHLIMIT = 0;
     private static final int    SEARCHTIMEOUT = 0;
 
@@ -55,7 +54,19 @@ public class JNDIDataBroker extends DataBroker
 
     public static final int SEARCH_SUB_TREE = 2;
 
+    /**
+     *    Magic value for search filters that returns only the DN of an entry
+     */
+
+    public static final String[] RETURN_ONLY_DN = new String[] {"1.1"};
+
+    /**
+     *    Magic value for search filters that returns all entries
+     */
+    public static final String RETURN_ALL_ENTRIES = "(objectClass=*)";
+
   	private LdapContext ctx;
+
     private boolean tracing = false;
     private boolean connectionError = true;
 
@@ -384,35 +395,9 @@ public class JNDIDataBroker extends DataBroker
         disconnect(); // clear out any existing cobwebs...
 
 		ConnectionData cData = request.conData;
-
-        String url = cData.url;
-
-        connectionError = false;
-
-        ctx = null;    // null the current directory context (can't be used again).
-
-        //  Try to get a directory context using above info.
-
         try
         {
-            dirOps = new CBGraphicsOps(cData);        	// this wraps up ctx for basic operations
-            ctx = dirOps.getContext();
-
-            if (ctx == null)
-                throw new NamingException("unable to open connection: unknown condition, no error returned.");
-
-            // make a bogus, fast, directory request to trigger some activity on the context.  Without this the
-            // context may *appear* to be open since jndi sometimes won't actually try to use it until a request is made
-            // (e.g. with DSML, SSL connections etc.)
-
-            String base = (request.conData.baseDN==null)?"":request.conData.baseDN;
-
-            //XXX bogus request failing - why??? (ans SASL error in jdk 1.4.0 - 1.4.1)
-            //ctx.search(base, "objectClass=*", new SearchControls(SearchControls.OBJECT_SCOPE, 0, 0, new String[]{}, false, false));
-            if (dirOps.exists(base) == false)
-                cData.baseDN = getActualDN(cData.baseDN);	//TE: (for bug 2363) - try to solve case sensitive DN problem.
-
-            // At this stage we should have a valid ldap context
+            openConnection(cData);
         }
         // can throw NamingException, GeneralSecurityException, IOException
         catch (Exception ne)        // An error has occurred.  Exit connection routine
@@ -425,9 +410,70 @@ public class JNDIDataBroker extends DataBroker
             return request;
         }
 
+
+        request.setStatus(true); 		// success!
+        request.finish();
+        return request;
+ 	}
+
+    /**
+     * This partially initialises the JNDI Broker by directly applying a context.
+     * (to be used for internal test cases only).
+     * @param testCtx
+     * @throws Exception
+     */
+    public void openTestConnection(LdapContext testCtx)
+            throws Exception
+    {
+        ctx = testCtx;
+        dirOps = new CBGraphicsOps(ctx);
+//        schemaOps = new SchemaOps(ctx);
+
+    }
+
+    /**
+     * This initialises the JNDIDataBroker with an active LDAP connection.
+     * Within 'normal JXplorer' this is usually called as the result of the evaluation of a
+     * DataConnectionQuery being picked up from the query queue and being executed by
+     * 'openConnection(DataConnectionQuery)', but it can also be executed directly by
+     * unthreaded code that wants to create a JNDIDataBroker directly (note however that this
+     * method may block for a minute or more if the LDAP server is unresponsive.)
+     * @param cData a connection data object.
+     * @throws Exception
+     */
+    public void openConnection(ConnectionData cData)
+              throws Exception
+    {
+        String url = cData.url;
+
+        connectionError = false;
+
+        ctx = null;    // null the current directory context (can't be used again).
+
+        //  Try to get a directory context using above info.
+
+        dirOps = new CBGraphicsOps(cData);        	// this wraps up ctx for basic operations
+        ctx = dirOps.getContext();
+
+        if (ctx == null)
+            throw new NamingException("unable to open connection: unknown condition, no error returned.");
+
+        // make a bogus, fast, directory request to trigger some activity on the context.  Without this the
+        // context may *appear* to be open since jndi sometimes won't actually try to use it until a request is made
+        // (e.g. with DSML, SSL connections etc.)
+
+        String base = (cData.baseDN==null)?"":cData.baseDN;
+
+        //XXX bogus request failing - why??? (ans SASL error in jdk 1.4.0 - 1.4.1)
+        //ctx.search(base, "objectClass=*", new SearchControls(SearchControls.OBJECT_SCOPE, 0, 0, new String[]{}, false, false));
+        if (dirOps.exists(base) == false)
+            cData.baseDN = getActualDN(cData.baseDN);	//TE: (for bug 2363) - try to solve case sensitive DN problem.
+
+        // At this stage we should have a valid ldap context
+
         try
         {
-            schemaOps = new SchemaOps(ctx); 
+            schemaOps = new SchemaOps(ctx);
         }        		// this wraps up ctx for basic operations
         catch (NamingException e)
         {
@@ -458,12 +504,7 @@ public class JNDIDataBroker extends DataBroker
             log.info("Successfully connected to " + url + " using " + cData.protocol + " version 2");
         else
             log.info("Successfully connected to " + url + " using " + cData.protocol + " version " + cData.version);
-
-        request.setStatus(true); 		// success!
-        request.finish();
-        return request;
- 	}
-	
+}
 	
 
    /**
@@ -1236,7 +1277,8 @@ public class JNDIDataBroker extends DataBroker
 	*  	support this functionality, but some include a
 	*  	<i>namingcontexts</i> attribute for their empty
 	*  	entry...
-	*  	@return the rootDN, or null if none was found.
+	*  	@return the rootDN, or null if none was found. Under rare circumstances this may return multiple roots,
+    *           however this will not always be handled gracefully!
 	*/
 
     public DN[] readFallbackRoot()
