@@ -469,7 +469,16 @@ public class SearchModel
 			return properties.getProperty(key);
 		
 		return null;	
-	}			
+	}
+
+    /**
+     *  inverse of 'saveValue()' - gets the value for a particular key and name
+     */
+    public String getValue(String name, String key)
+
+    {
+        return getValue(name + "." + key);
+    }
 
    /**
     *	Checks if the property file contains the value.  If it does it gets the
