@@ -196,6 +196,9 @@ public class SmartTree extends JTree
     /**
      * returns a vector of DNs being the all inclusive list of all DNs
      * in the subtree from the given apex DN.  Used by ldif save ftn.
+     * Includes 'structural' nodes that are simply in there to fill out
+     * a tree of search results (e.g. org units in a 'people' search).
+     * If you want *just* the results of a search, use 'getAllSearchResultNodes()'
      *
      * @param start the node to start listing search result entries from.
      * @return a ArrayList of DNs
@@ -230,6 +233,47 @@ public class SmartTree extends JTree
         }
     }
 
+    /**
+     * returns a vector of DNs being the all inclusive list of all DNs
+     * in the subtree created from a search.  This *skips* structural nodes
+     * that are created simply to 'fill out the tree with parent nodes (
+     * e.g. org units created to display a 'person' search).
+     *
+     *
+     * @param start the node to start listing search result entries from.
+     * @return a ArrayList of DNs
+     */
+
+    public ArrayList <DN> getAllSearchResultNodes(DN start)
+    {
+        if (start == null) return new ArrayList<DN>(0);          // sanity check
+        SmartNode startNode = treeModel.getNodeForDN(start);              // need the smart node to find children
+        if (startNode == null) return new ArrayList<DN>(0);           // another sanity check
+
+        try
+        {
+            ArrayList <DN> result = new ArrayList<DN>(10);
+
+            if (startNode.isStructural() == false)
+                result.add(start);                    // only add 'real' nodes from search results, skip structural nodes used to 'fill out' tree structure
+
+            Enumeration children = startNode.children();  // find children of 'from'
+            while (children.hasMoreElements())
+            {
+                DN next = new DN(start);
+                SmartNode child = (SmartNode) children.nextElement();
+                next.addChildRDN(child.getRDN());
+                result.addAll(getAllSearchResultNodes(next));
+            }
+            return result;
+        }
+        catch (Exception e)
+        {
+            log.log(Level.WARNING, "error in SmartTree dump: ", e);
+            return new ArrayList<DN>(0);
+        }
+    }
+
     /**
      * This sets the root of the tree, creating the nodes
      * necessary to display it.  A small wrinkle: the
