@@ -4,7 +4,6 @@ import com.ca.commons.cbutil.*;
 import com.ca.commons.naming.*;
 import com.ca.directory.jxplorer.*;
 import com.ca.directory.jxplorer.broker.DataBrokerQueryInterface;
-import com.ca.directory.jxplorer.tree.NewEntryWin;
 import com.ca.directory.jxplorer.viewer.tableviewer.*;
 import com.ca.directory.jxplorer.viewer.tableviewer.AttributeValue;
 
@@ -113,7 +112,7 @@ public class TableAttributeEditor extends JPanel
         // Set the renderer for the attribute type...
         final AttributeTypeCellRenderer typeRenderer = new AttributeTypeCellRenderer();
 
-        attributeTable.setDefaultRenderer(AttributeType.class, typeRenderer);
+        attributeTable.setDefaultRenderer(AttributeNameAndType.class, typeRenderer);
 
         // Set the renderer for the attribute value...
         final AttributeValueCellRenderer valueRenderer = new AttributeValueCellRenderer();
@@ -216,7 +215,7 @@ public class TableAttributeEditor extends JPanel
                 attributeTable.addRowSelectionInterval(row, row);
                 attributeTable.repaint();
 
-                popupTableTool.registerCurrentRow((AttributeType) attributeTable.getValueAt(row, 0), (AttributeValue) attributeTable.getValueAt(row, 1), row, tableData.getRDN());         // active path also set by valueChanged
+                popupTableTool.registerCurrentRow((AttributeNameAndType) attributeTable.getValueAt(row, 0), (AttributeValue) attributeTable.getValueAt(row, 1), row, tableData.getRDN());         // active path also set by valueChanged
                 popupTableTool.show(attributeTable, e.getX(), e.getY());
                 popupTableTool.registerCellEditor(myEditor);    //TE: for bug fix 3107.
                 return true;
@@ -345,7 +344,8 @@ public class TableAttributeEditor extends JPanel
             return;
 
         // EJP 17 August 2010.
-        String[] opAttrs = {"+"};
+        // CB 14 August 2012 - some directories (looking at you Active Directory) don't support the '+' operator... so do it manually as well...
+        String[] opAttrs = {"+","createTimeStamp", "creatorsName", "entryFlags", "federationBoundary", "localEntryID", "modifiersName", "modifyTimeStamp", "structuralObjectClass", "subordinateCount", "subschemaSubentry"};
         DXEntry entry = null;
         try
         {
@@ -362,7 +362,9 @@ public class TableAttributeEditor extends JPanel
 				while (ne.hasMore())
 				{
 					DXAttribute att = (DXAttribute)ne.next();
-					buffy.append(att.getName()+": "+att.get().toString()+"\n\n");
+					buffy.append(att.getName()+": "+att.get().toString()+"\n");
+
+                    tableData.insertOperationalAttribute(att);
 				}	
 			}
 			finally
@@ -371,15 +373,19 @@ public class TableAttributeEditor extends JPanel
 				    ne.close();
 			}
 
+            tableData.fireTableDataChanged();
+
+            /*
 			// Dialog setup...
 			JTextArea area = new JTextArea(buffy.toString());
 			area.setFont(new Font("SansSerif", Font.PLAIN, 11));
 			area.setLineWrap(true);
 			area.setWrapStyleWord(true);
 			JScrollPane scrollPane = new JScrollPane(area);
-			scrollPane.setPreferredSize(new Dimension(300, 125));
+			scrollPane.setPreferredSize(new Dimension(400, 500));
 			scrollPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
 			JOptionPane.showMessageDialog(jx, scrollPane, CBIntText.get("Properties (Operational Attributes)"), JOptionPane.INFORMATION_MESSAGE);
+			*/
 		}
         catch (NamingException e)
         {
@@ -531,7 +537,7 @@ public class TableAttributeEditor extends JPanel
 
         if (entry != null && entry.size() == 0)
         {
-// If there is an entry and it's size is zero - it's probably is a virtual entry.
+// If there is an entry and its size is zero - it's probably a virtual entry.
 // We need to give the user the option of adding an object class to it i.e. so that
 // it can be added to the directory as a real entry.
 //
