@@ -7,7 +7,7 @@ import javax.naming.directory.Attribute;
 import javax.naming.directory.BasicAttribute;
 import javax.swing.event.TableModelEvent;
 import javax.swing.table.AbstractTableModel;
-import java.util.Vector;
+import java.util.ArrayList;
 
 public class AttributeTableModel extends AbstractTableModel
 {
@@ -16,8 +16,8 @@ public class AttributeTableModel extends AbstractTableModel
 
     DXEntry oldEntry;                        // the original, unedited data
 
-    Vector attributeTypes = new Vector();   // vector of string IDs
-    Vector attributeValues = new Vector();   // vector of attributeValues
+    ArrayList<AttributeNameAndType> attributeTypes = new ArrayList<AttributeNameAndType>();   // vector of string IDs
+    ArrayList<AttributeValue> attributeValues = new ArrayList<AttributeValue>();   // vector of attributeValues
 
     /**
      * The number of naming values (e.g. the length of the
@@ -56,12 +56,12 @@ public class AttributeTableModel extends AbstractTableModel
 
     /**
      * Returns the class of the objects in the different columns:
-     * AttributeType.class for col 0, AttributeValue.class for col 1.
+     * AttributeNameAndType.class for col 0, AttributeValue.class for col 1.
      */
 
     public Class getColumnClass(int c)
     {
-        return (c == 1) ? AttributeValue.class : AttributeType.class;
+        return (c == 1) ? AttributeValue.class : AttributeNameAndType.class;
     }
 
     /**
@@ -86,11 +86,11 @@ public class AttributeTableModel extends AbstractTableModel
         {
             if (aValue instanceof AttributeValue)  // replace an attributeValues
             {
-                attributeValues.set(row, aValue);
+                attributeValues.set(row, (AttributeValue)aValue);
             }
             else                                    // ... or update it.
             {
-                ((AttributeValue) attributeValues.elementAt(row)).update(aValue);
+                ((AttributeValue) attributeValues.get(row)).update(aValue);
             }
 
             fireTableCellUpdated(row, col);
@@ -116,7 +116,7 @@ public class AttributeTableModel extends AbstractTableModel
      */
     public Object getValueAt(int row, int col)
     {
-        return (col == 0) ? attributeTypes.elementAt(row) : attributeValues.elementAt(row);
+        return (col == 0) ? attributeTypes.get(row) : attributeValues.get(row);
     }
 
     /**
@@ -126,9 +126,15 @@ public class AttributeTableModel extends AbstractTableModel
     {
         if (col == 0) return false;  // can't edit attribute names
         if (col > 1) return false;   // should never happen.
-        if (attributeTypes.elementAt(row).toString().equalsIgnoreCase("objectclass"))
+        AttributeNameAndType att = attributeTypes.get(row);
+
+
+        if (att.toString().equalsIgnoreCase("objectclass"))
             return false;            // can't edit object classes (this way)
 
+        if (att.isOperational())
+            return false;           // can't edit operational attributes either...
+
         return true;
     }
 
@@ -151,7 +157,7 @@ public class AttributeTableModel extends AbstractTableModel
          */
 
         for (int i = 0; i < attributeValues.size(); i++)
-            ((AttributeValue) attributeValues.elementAt(i)).reset();
+            ((AttributeValue) attributeValues.get(i)).reset();
 
         /*
          *    Return the naming attribute list to the original
@@ -227,7 +233,7 @@ public class AttributeTableModel extends AbstractTableModel
             DXNamingEnumeration mandatory = (DXNamingEnumeration) entry.getMandatory();
 
             while (mandatory.hasMore())
-                insertAttribute(((DXAttribute) mandatory.next()), AttributeType.MANDATORY);
+                insertAttribute(((DXAttribute) mandatory.next()), AttributeNameAndType.MANDATORY);
 
             /*
              *    Then add the 'MAY' contain optional attributes.
@@ -243,7 +249,7 @@ public class AttributeTableModel extends AbstractTableModel
                 if (mandatory.contains(temp) == false && (temp.size() > 0) && (temp.get() != null))
                 {
                     temp.sort();
-                    insertAttribute(temp, AttributeType.NORMAL);
+                    insertAttribute(temp, AttributeNameAndType.NORMAL);
                 }
             }
 
@@ -258,7 +264,7 @@ public class AttributeTableModel extends AbstractTableModel
                 DXAttribute temp = (DXAttribute) possible.next();
                 if (mandatory.contains(temp) == false && ((temp.size() == 0) || (temp.get() == null)))
                 {
-                    insertAttribute(temp, AttributeType.NORMAL);
+                    insertAttribute(temp, AttributeNameAndType.NORMAL);
                 }
             }
 
@@ -298,6 +304,23 @@ public class AttributeTableModel extends AbstractTableModel
         }
     }
 
+    //TODO: this all seems a bit clunky - can we simplify it somehow?  There seems to be a lot of
+    //TODO: overlap between AttributeNameAndType and AttributeValue?
+    public void insertOperationalAttribute(DXAttribute att)
+    {
+        attributeTypes.add(0, new AttributeNameAndType(att.getID(), AttributeNameAndType.OPERATIONAL));
+        try
+        {
+            String val = att.get().toString();
+            attributeValues.add(0, new AttributeValue(att, val, false));
+        }
+        catch (NamingException e)
+        {
+            attributeValues.add(0,new AttributeValue(att, "error")); // shouldn't ever happen...
+        }
+        noRows++;
+
+    }
 
     /**
      * Adds a single attribute, and (possibly multiple, or blank) values
@@ -425,27 +448,29 @@ public class AttributeTableModel extends AbstractTableModel
 
     public void addAttribute(AttributeValue val, int type)
     {
-        attributeTypes.add(new AttributeType(val.getID(), (type == AttributeType.MANDATORY)));
+        AttributeNameAndType newAtt = new AttributeNameAndType(val.getID(), (type == AttributeNameAndType.MANDATORY));
+        attributeTypes.add(newAtt);
         attributeValues.add(val);
         noRows++;
     }
 
     public void addAttribute(AttributeValue val, int type, int indexPos)
     {
-        attributeTypes.add(indexPos, new AttributeType(val.getID(), (type == AttributeType.MANDATORY)));
+        AttributeNameAndType newAtt = new AttributeNameAndType(val.getID(), (type == AttributeNameAndType.MANDATORY));
+        attributeTypes.add(indexPos, newAtt);
         attributeValues.add(indexPos, val);
         noRows++;
     }
 
     public void deleteAttribute(String ID, int indexPos)
     {
-        if (attributeTypes.elementAt(indexPos).toString().equals(ID))
+        if (attributeTypes.get(indexPos).toString().equals(ID))
         {
-            ((AttributeValue) attributeValues.elementAt(indexPos)).update(new String("")); // empty string required to not break table display with nulls (I think)
+            ((AttributeValue) attributeValues.get(indexPos)).update(new String("")); // empty string required to not break table display with nulls (I think)
         }
         else
             System.err.println("Internal error: attempt to delete attribute with invalid ID in AttributeTableModel" +
-                    "\n att name = " + attributeTypes.elementAt(indexPos).toString() + " ID = " + ID);
+                    "\n att name = " + attributeTypes.get(indexPos).toString() + " ID = " + ID);
     }
 
     public void fireChange()
@@ -539,11 +564,11 @@ public class AttributeTableModel extends AbstractTableModel
 
         for (int i = 0; i < attributeTypes.size(); i++)
         {
-            currentAttributeValue = (AttributeValue) attributeValues.elementAt(i);
+            currentAttributeValue = (AttributeValue) attributeValues.get(i);
             if (!currentAttributeValue.isEmpty())
             {
                 // get the ID of the current Att
-                id = attributeTypes.elementAt(i).toString();
+                id = attributeTypes.get(i).toString();
 
                 // test value for emptiness
                 Object value = currentAttributeValue.value();
@@ -583,9 +608,9 @@ public class AttributeTableModel extends AbstractTableModel
     {
         BasicAttribute returnAtt = new BasicAttribute(ID);
         for (int i = 0; i < attributeTypes.size(); i++)
-            if (ID.equals(attributeTypes.elementAt(i).toString()))
+            if (ID.equals(attributeTypes.get(i).toString()))
             {
-                Object o = ((AttributeValue) attributeValues.elementAt(i)).value();
+                Object o = ((AttributeValue) attributeValues.get(i)).value();
 
                 // don't allow zero length string attributes, or 'empty' strings of just a single space...
                 if (o != null && o instanceof String)
@@ -614,9 +639,9 @@ public class AttributeTableModel extends AbstractTableModel
     {
         for (int i = 0; i < attributeTypes.size(); i++)
         {
-            if (((AttributeType) attributeTypes.elementAt(i)).toString().equals(attributeTypeName))
+            if (((AttributeNameAndType) attributeTypes.get(i)).toString().equals(attributeTypeName))
             {
-                return ((AttributeType) attributeTypes.elementAt(i)).isMandatory();
+                return ((AttributeNameAndType) attributeTypes.get(i)).isMandatory();
             }
         }
         System.err.println("unable to find type name " + attributeTypeName);
@@ -636,7 +661,7 @@ public class AttributeTableModel extends AbstractTableModel
     //    continue until no types left.
     public boolean checkMandatoryAttributesSet()
     {
-        AttributeType type, testType;
+        AttributeNameAndType type, testType;
         AttributeValue value;
         String ID = "";
         boolean inDoubt = false;
@@ -644,7 +669,7 @@ public class AttributeTableModel extends AbstractTableModel
 
         while (i < noRows)                                            // for all rows
         {
-            type = (AttributeType) attributeTypes.elementAt(i);
+            type = (AttributeNameAndType) attributeTypes.get(i);
 
             if (type.isMandatory())                                // find mandatory types
             {
@@ -656,12 +681,12 @@ public class AttributeTableModel extends AbstractTableModel
                 {                                                  // mandatory attribute...
                     if (inDoubt)                                   // ... until we find a valid value
                     {
-                        value = (AttributeValue) attributeValues.elementAt(i);
+                        value = (AttributeValue) attributeValues.get(i);
                         if (value.isEmpty() == false)                // !!! found a valid value
                             inDoubt = false;
                     }
                     i++;
-                    if (i < noRows) testType = (AttributeType) attributeTypes.elementAt(i);
+                    if (i < noRows) testType = (AttributeNameAndType) attributeTypes.get(i);
                 }
 
                 if (inDoubt)         // Iff still in doubt, means no valid value was found
@@ -681,12 +706,12 @@ public class AttributeTableModel extends AbstractTableModel
      * sets the currentValue object to be a naming value.
      */
 
-    public void removeNamingComponent(AttributeType currentType, AttributeValue currentValue)
+    public void removeNamingComponent(AttributeNameAndType currentType, AttributeValue currentValue)
     {
 
         try
         {
-            String type = currentType.getValue();
+            String type = currentType.getName();
             String value = currentValue.getStringValue();
 
             if ("".equals(type) || "".equals(value)) // which it really, really shouldn't...
@@ -754,10 +779,10 @@ public class AttributeTableModel extends AbstractTableModel
     }
 
 
-    public void addNamingComponent(AttributeType currentType, AttributeValue currentValue)
+    public void addNamingComponent(AttributeNameAndType currentType, AttributeValue currentValue)
     {
 
-        String type = currentType.getValue();
+        String type = currentType.getName();
         String value = currentValue.getStringValue();
 
         if ("".equals(type) || "".equals(value)) // which it really, really shouldn't...
@@ -789,7 +814,7 @@ public class AttributeTableModel extends AbstractTableModel
     public boolean changedByUser()
     {
         for (int i = 0; i < attributeValues.size(); i++)
-            if (((AttributeValue) attributeValues.elementAt(i)).changed())
+            if (((AttributeValue) attributeValues.get(i)).changed())
                 return true;
 
         return false;
